summaryrefslogtreecommitdiff
path: root/doc/reference/javascript_reference.rst
diff options
context:
space:
mode:
authorSébastien Theys <seb@odoo.com>2019-06-21 11:09:50 +0000
committerSébastien Theys <seb@odoo.com>2019-06-21 11:09:50 +0000
commit344614b54a2aa7799a551306b31c00f52ed4f999 (patch)
tree9ed4459199e35092f473e7550e552e3c254ba604 /doc/reference/javascript_reference.rst
parent9150c3d2c9b3e0af241cb45f710bfcb59d9cb7a1 (diff)
[IMP] base, product: optimize image compute when image is not set
All of those fields `__get__` and method calls have a cost, it is small but when done for many records it adds up, so they are better not done. When creating 1000 products without image, this compute takes: 47ms +/- 1ms before the commit 37ms +/- 1ms after the commit That's around 20% less. Part of task-1918881 closes odoo/odoo#34294 Signed-off-by: Jérémy Kersten (jke) <jke@openerp.com>
Diffstat (limited to 'doc/reference/javascript_reference.rst')
0 files changed, 0 insertions, 0 deletions